@@ -78,7 +78,7 @@ echo ""
 $ECHO "Ok, install to $BINDIR and $LIBDIR? [y]/n: $END"
 read yn
 if [ "x$yn" != "xn" -a "x$yn" != "xN" ]; then
-    sed -e "s#/usr/dict/ger-eng.txt#$LIBDIR/ger-eng.txt#" ding > /tmp/ding.$$
+    sed -e "s#/usr/share/dict/ger-eng.txt#$LIBDIR/ger-eng.txt#" ding > /tmp/ding.$$
  
     echo /bin/cp ding "$BINDIR/ding"
     /bin/mv /tmp/ding.$$ "$BINDIR/ding"
